@@ -6,3 +6,6 @@ pub mod mysql;
 
 #[cfg(feature = "postgres")]
 pub mod postgres;
+
+#[cfg(feature = "sqlite")]
+pub mod sqlite;
